==> breads-ad-1.0.5.tar.gz: breads-ad-1.0.5/README.md <==
<div align="center">
  <h1> 🍞 BREADS </h1>
  <img src="https://i.imgur.com/uGdGDeo.png" width=690>
  <p> <b>BREADS (BREaking Active Directory Security) </b> is a project created by security researchers focused on attacking Active Directory environments </p>
</div>

<p align="center">
    <img src="https://img.shields.io/github/license/inferigang/breads?color=pink&logo=github&style=for-the-badge">
    <img src="https://img.shields.io/github/issues/inferigang/breads?color=pink&logo=github&style=for-the-badge">
    <img src="https://img.shields.io/github/stars/inferigang/breads?color=pink&logo=github&style=for-the-badge">
    <img src="https://img.shields.io/github/forks/inferigang/breads?color=pink&logo=github&style=for-the-badge">
    <img src="https://img.shields.io/github/languages/code-size/inferigang/breads?color=pink&logo=github&style=for-the-badge">
</p>

___

<br>

## ⚡ Installing / Getting Started

<p> A quick guide on how to install and use BREADS. </p>

### Install with pipx (recommended)
- `pipx install git+https://github.com/inferigang/breads --include-deps`

### Not recommended
1. Clone the repository with: `git clone https://github.com/inferigang/breads.git`
2. Install the libraries with: `pip3 install -r requirements.txt` or `python3 setup.py install`
3. Run BREADS with: `python3 src/main.py`

<br>

## ✨ Features
- Profile creation
- +6 Modules (Enum Users, Disabled Accounts, Domain Controllers and more...)
- Low RAM and CPU usage
- Open-Source
- Python ❤️

<br>

## 🎥 Preview
<img src="https://i.imgur.com/RuwMBuX.png">

<br>

## 📚 To-Do
- [ ] Add more modules
- [ ] Improve profile creation
- [ ] Store data on SGBD
- [ ] Create a UI

<br>

## 🙏 Credits / Inspiration
- CrackMapExec
- Impacket
- BloodHound

<br>

## 🤡 And a good meme...
<img src="https://i.imgur.com/uPrUvi5.png" width=512>

## ⚠️ Warning
- The developer is not responsible for any malicious use of this tool.

==> breads-ad-1.0.7.tar.gz: breads-ad-1.0.7/README.md <==
<div align="center">
  <h1> 🍞 BREADS </h1>
  <img src="https://i.imgur.com/uGdGDeo.png" width=690>
  <p> <b>BREADS (BREaking Active Directory Security) </b> is a project created by security researchers focused on attacking Active Directory environments </p>
</div>

<p align="center">
    <img src="https://img.shields.io/github/license/inferigang/breads?color=pink&logo=github&style=for-the-badge">
    <img src="https://img.shields.io/github/issues/inferigang/breads?color=pink&logo=github&style=for-the-badge">
    <img src="https://img.shields.io/github/stars/inferigang/breads?color=pink&logo=github&style=for-the-badge">
    <img src="https://img.shields.io/github/forks/inferigang/breads?color=pink&logo=github&style=for-the-badge">
    <img src="https://img.shields.io/github/languages/code-size/inferigang/breads?color=pink&logo=github&style=for-the-badge">
</p>

___

<br>

## ⚡ Installing / Getting Started

<p> A quick guide on how to install and use BREADS. </p>

### Install with pipx (recommended)
- `pipx install git+https://github.com/inferigang/breads --include-deps`

### Not recommended
1. Clone the repository with: `git clone https://github.com/inferigang/breads.git`
2. Install the libraries with: `pip3 install -r requirements.txt` or `python3 setup.py install`
3. Run BREADS with: `python3 src/main.py`

<br>

## ✨ Features
- Profile creation
- +6 Modules (Enum Users, Disabled Accounts, Domain Controllers and more...)
- Low RAM and CPU usage
- Open-Source
- Python ❤️

<br>

## 🎥 Preview
<img src="https://i.imgur.com/MaflBgp.png" width=780>

<br>

## 📚 To-Do
- [ ] Add more modules (WIP)
- [ ] Improve profile creation
- [ ] Store data on SGBD
- [ ] Create a UI

<br>

## 🙏 Credits / Inspiration
- CrackMapExec
- Impacket
- BloodHound

<br>

## 🤡 And a good meme...
<img src="https://i.imgur.com/uPrUvi5.png" width=512>

## ⚠️ Warning
- The developer is not responsible for any malicious use of this tool.
